@@ -3,4 +3,5 @@ utils::globalVariables(c("AE_ONSET_DT_INT", "AE_SEV_GD", "AE_VERBATIM_TRM_TXT",
                          "ae_category", "ae_detail", "ae_grade_code_dyn_std", "anova", "as.formula", "binomial",
                          "cl", "desc", "drug1_ae", "gender_code", "group", "ind", "indH", "indH_per", "instance", "join",
                          "label", "median", "na.fail", "stopCluster", "time_max", "time_median", "time_min", "where",
-                         "ID", "est", "term", "lower", "upper", "significance", "model1", "reorder"))
\ No newline at end of file
+                         "ID", "est", "term", "lower", "upper", "significance", "model1", "reorder", "ID_label", 
+                         "instances", "hp_instances"))
\ No newline at end of file
